@@ -269,9 +269,6 @@ class CircusCtl(cmd.Cmd, object):
     def start(self, globalopts):
         self.autocomplete()
 
-        if globalopts['timeout'] < 30:
-            globalopts['args'].timeout = globalopts['timeout'] = 30
-
         self.controller.globalopts = globalopts
 
         args = globalopts['args']
