@@ -59,7 +59,7 @@ class Get(Command):
 
     def message(self, *args, **opts):
         if len(args) < 2:
-            raise ArgumentError("number of arguments invalid")
+            raise ArgumentError("Invalid number of arguments")
 
         return self.make_message(name=args[0], keys=args[1:])
 
