@@ -1,7 +1,6 @@
 import socket
-
+from zmq.eventloop import ioloop
 from circus.plugins import CircusPlugin
-from circus._zmq import ioloop
 
 
 class StatsdClient(object):
@@ -105,13 +104,16 @@ class FullStats(BaseObserver):
             cpus = []
             mems = []
 
-            for sub_info in stats.itervalues():
-                if isinstance(sub_info,  basestring):
-                    # dead processes have a string instead of actual info
-                    # ignore that
-                    continue
-                cpus.append(sub_info['cpu'])
-                mems.append(sub_info['mem'])
+            for sub_name, sub_info in stats.iteritems():
+                if isinstance(sub_info,  dict):
+                    cpus.append(sub_info['cpu'])
+                    mems.append(sub_info['mem'])
+                elif sub_name == "spawn_count":
+                    # spawn_count info is in the same level as processes
+                    # dict infos, so if spawn_count is given, take it and
+                    # continue
+                    self.statsd.gauge("_stats.%s.spawn_count" % name,
+                                      sub_info)
 
             self.statsd.gauge("_stats.%s.watchers_num" % name, len(cpus))
 
