@@ -22,8 +22,20 @@ class SysHandler(object):
         self.controller = controller
 
         # init signals
-        logger.info('Registring signals...')
+        logger.info('Registering signals...')
+        self._old = {}
+        self._register()
+
+    def stop(self):
+        for sig, callable in self._old.items():
+            try:
+                signal.signal(sig, callable)
+            except ValueError:
+                pass
+
+    def _register(self):
         for sig in self.SIGNALS:
+            self._old[sig] = signal.getsignal(sig)
             signal.signal(sig, self.signal)
 
         # Don't let SIGQUIT and SIGUSR1 disturb active requests
@@ -32,7 +44,7 @@ class SysHandler(object):
             signal.siginterrupt(signal.SIGQUIT, False)
             signal.siginterrupt(signal.SIGUSR1, False)
 
-    def signal(self, sig, frame):
+    def signal(self, sig, frame=None):
         signame = self.SIG_NAMES.get(sig)
         logger.info('Got signal SIG_%s' % signame.upper())
 
